@@ -53,8 +53,6 @@
 #' strata specific results (when strata has been specified).
 #' @param minCellCount The minimum number of events to reported, below which
 #' results will be obscured. If 0, all results will be reported.
-#' @param temporary If TRUE, temporary tables will be used throughout. If
-#' FALSE, permanent tables will be created in the write_schema of the cdm.
 #' @param returnParticipants Either TRUE or FALSE. If TRUE references to
 #' participants from the analysis will be returned allowing for further
 #' analysis. Note, if using permanent tables and returnParticipants is TRUE,
@@ -88,7 +86,6 @@ estimateIncidence <- function(cdm,
                               minCellCount = 5,
                               strata = list(),
                               includeOverallStrata = TRUE,
-                              temporary = TRUE,
                               returnParticipants = FALSE) {
   startCollect <- Sys.time()
 
@@ -104,7 +101,7 @@ estimateIncidence <- function(cdm,
   checkInputEstimateIncidence(
     cdm, denominatorTable, outcomeTable, denominatorCohortId,
     outcomeCohortId, interval, completeDatabaseIntervals,
-    outcomeWashout, repeatedEvents, minCellCount, temporary,
+    outcomeWashout, repeatedEvents, minCellCount,
     returnParticipants
   )
 
@@ -149,7 +146,7 @@ estimateIncidence <- function(cdm,
   )
 
   # get outcomes + cohort_start_date & cohort_end_date
-  outcome <- cdm[[outcomeTable]] %>%
+  cdm[[paste0(tablePrefix, "_inc_1")]] <- cdm[[outcomeTable]] %>%
     dplyr::filter(.data$cohort_definition_id %in% .env$outcomeCohortId) %>%
     dplyr::rename(
       "outcome_cohort_id" = "cohort_definition_id",
@@ -164,16 +161,14 @@ estimateIncidence <- function(cdm,
                       "cohort_end_date")) %>%
         dplyr::distinct(),
       by = "subject_id"
-    )
-
-  outcome <- outcome %>%
+    ) %>%
     dplyr::compute(
       name = paste0(tablePrefix, "_inc_1"),
       temporary = FALSE,
       overwrite = TRUE
     )
 
-  outcome <- outcome %>%
+  cdm[[paste0(tablePrefix, "_inc_2")]] <- cdm[[paste0(tablePrefix, "_inc_1")]] %>%
     # most recent outcome starting before cohort start per person
     dplyr::filter(.data$outcome_start_date < .data$cohort_start_date) %>%
     dplyr::group_by(
@@ -185,20 +180,17 @@ estimateIncidence <- function(cdm,
       max(.data$outcome_start_date, na.rm = TRUE)) %>%
     dplyr::union_all(
       # all starting during cohort period
-      outcome %>%
+      cdm[[paste0(tablePrefix, "_inc_1")]] %>%
         dplyr::filter(.data$outcome_start_date >= .data$cohort_start_date) %>%
         dplyr::filter(.data$outcome_start_date <= .data$cohort_end_date)
-    )
-
-  outcome <- outcome %>%
+    ) %>%
     dplyr::compute(
       name = paste0(tablePrefix, "_inc_2"),
       temporary = FALSE,
       overwrite = TRUE
     )
 
-
-  outcome <- outcome %>%
+  cdm[[paste0(tablePrefix, "_inc_3")]] <-  cdm[[paste0(tablePrefix, "_inc_2")]] %>%
     dplyr::group_by(
       .data$subject_id,
       .data$cohort_start_date,
@@ -206,25 +198,17 @@ estimateIncidence <- function(cdm,
     ) %>%
     dbplyr::window_order(.data$outcome_start_date) %>%
     dplyr::mutate(index = rank()) %>%
-    dplyr::ungroup()
-
-  outcome <- outcome %>%
+    dplyr::ungroup() %>%
     dplyr::compute(
       name = paste0(tablePrefix, "_inc_3"),
       temporary = FALSE,
       overwrite = TRUE
     )
 
-  # add to cdm reference
-  workingOutcomeTable <- paste0("working_", outcomeTable)
-  cdm <- CDMConnector::insertTable(cdm = cdm,
-                            name = workingOutcomeTable,
-                            table = outcome,
-                            overwrite = TRUE)
-  cdm[[workingOutcomeTable]] <- cdm[[workingOutcomeTable]] %>%
+  cdm[[paste0(tablePrefix, "_inc_4")]] <- cdm[[paste0(tablePrefix, "_inc_3")]] %>%
     dplyr::select(-"outcome_end_date") %>%
     dplyr::full_join(
-      outcome %>%
+      cdm[[paste0(tablePrefix, "_inc_3")]] %>%
         dplyr::mutate(index = .data$index + 1) %>%
         dplyr::rename("outcome_prev_end_date" = "outcome_end_date") %>%
         dplyr::select(-"outcome_start_date"),
@@ -233,9 +217,7 @@ estimateIncidence <- function(cdm,
         "cohort_end_date", "outcome_cohort_id", "index"
       )
     ) %>%
-    dplyr::select(-"index")
-
-  outcome <- outcome %>%
+    dplyr::select(-"index") %>%
     dplyr::compute(
       name = paste0(tablePrefix, "_inc_4"),
       temporary = FALSE,
@@ -270,12 +252,11 @@ estimateIncidence <- function(cdm,
       "Getting incidence for analysis {counter} of {length(studySpecs)}"
     ))
 
-
     workingInc <- getIncidence(
       cdm = cdm,
       denominatorTable = denominatorTable,
       denominatorCohortId = x$denominator_cohort_id,
-      outcomeTable = workingOutcomeTable,
+      outcomeTable = paste0(tablePrefix, "_inc_4"),
       outcomeCohortId = x$outcome_cohort_id,
       interval = x$interval,
       completeDatabaseIntervals = x$complete_database_intervals,
@@ -296,13 +277,11 @@ estimateIncidence <- function(cdm,
       dplyr::mutate(
         outcome_cohort_id = x$outcome_cohort_id,
         denominator_cohort_id = x$denominator_cohort_id,
-        analysis_interval = x$interval,
-        analysis_outcome_washout = x$outcome_washout,
-        analysis_repeated_events = x$repeated_events,
         analysis_min_cell_count = .env$minCellCount,
         analysis_id = x$analysis_id
       ) %>%
-      dplyr::relocate("analysis_id")
+      dplyr::relocate("analysis_id") %>%
+      dplyr::mutate(analysis_outcome_washout = as.character(.data$analysis_outcome_washout))
 
     workingIncAttrition <- workingInc[["attrition"]] %>%
       dplyr::mutate(analysis_id = x$analysis_id) %>%
@@ -415,12 +394,10 @@ estimateIncidence <- function(cdm,
               )
             ),
             by = "subject_id"
-          ) %>%
-          dplyr::compute(
-            name = paste0(tablePrefix, "_p_", i),
-            temporary = FALSE,
-            overwrite = TRUE
           )
+        cdm <- omopgenerics::insertTable(cdm = cdm,
+                                         name = paste0(tablePrefix, "_p_", i),
+                                         table = participants)
       }
     }
 
@@ -433,7 +410,11 @@ estimateIncidence <- function(cdm,
       "inc_participants"
     ))
 
-    participants <- participants %>%
+
+    cdm <- omopgenerics::insertTable(cdm = cdm,
+                                     name = paste0("inc_participants", p),
+                                     table = participants)
+    cdm[[paste0("inc_participants", p)]] <- cdm[[paste0("inc_participants", p)]] %>%
       dplyr::compute(
         name = paste0("inc_participants", p),
         temporary = FALSE,
@@ -473,8 +454,9 @@ estimateIncidence <- function(cdm,
 
   # return results as an IncidencePrevalenceResult class
   attr(irs, "attrition") <- attrition
+  attr(irs, "settings") <- analysisSettings
   if (returnParticipants == TRUE) {
-    attr(irs, "participants") <- participants
+    attr(irs, "participants") <- cdm$inc_participants1
   }
   class(irs) <- c("IncidencePrevalenceResult", "IncidenceResult", class(irs))
 
