@@ -1,4 +1,5 @@
 test_that("dbms test", {
+  testthat::skip
   # Update  to your database details as appropriate here
   skip_if(Sys.getenv("DB_SERVER_cdmgold202007_dbi") == "")
   db <- DBI::dbConnect(RPostgres::Postgres(),
@@ -15,12 +16,37 @@ test_that("dbms test", {
   )
   dplyr::count(cdm$person)
 
-  timings <- benchmarkIncidencePrevalence(cdm,
-    nOutcomes = 1,
-    prevOutcomes = 0.10
+  cdm <- generateDenominatorCohortSet(
+    cdm = cdm,
+    name = "denom" ,
+    cohortDateRange = c(as.Date("2000-01-01"), as.Date("2022-01-01")),
+    ageGroup =list(
+      c(18, 150),
+      c(18, 49),
+      c(50, 59),
+      c(60, 69),
+      c(70, 79),
+      c(80, 150)
+    ),
+    sex = c("Male", "Female", "Both"),
+    daysPriorObservation = 365
   )
-  expect_true(tibble::is_tibble(timings))
 
+  cdm <- CDMConnector::generate_concept_cohort_set(cdm,
+                                                   concept_set =
+                                                     list(a = 4050747,
+                                                         b = 4077375))
+  expect_no_error(estimateIncidence(cdm,
+                    denominatorTable = "denom",
+                    outcomeTable = "cohort",
+                    outcomeCohortId = 1,
+                    temporary = FALSE,
+                    returnParticipants = TRUE))
+  expect_no_error(estimatePointPrevalence(cdm,
+                    denominatorTable = "denom",
+                    outcomeTable = "cohort",
+                    temporary = FALSE,
+                    returnParticipants = TRUE))
 
   # Drop any permanent tables created
   CDMConnector::listTables(attr(cdm, "dbcon"),
@@ -76,11 +102,30 @@ test_that("postgres test", {
                     prefix = "incp_")
  )
 
+ profvis::profvis({
+   cdm <- generateDenominatorCohortSet(
+     cdm = cdm,
+     name = "denom",
+     cohortDateRange = c(as.Date("2000-01-01"), as.Date("2022-01-01")),
+     ageGroup =list(
+       c(18, 150),
+       c(18, 49),
+       c(50, 59),
+       c(60, 69),
+       c(70, 79),
+       c(80, 150)
+     ),
+     sex = c("Male", "Female", "Both"),
+     daysPriorObservation = 365
+   )
+ })
+
  cdm <- CDMConnector::generateConceptCohortSet(cdm = cdm, name = "test_outcome",
                                                conceptSet = list("a" = 381566,
                                                                  "b" = 138525),
                                                overwrite = TRUE)
 
+
  timings <- benchmarkIncidencePrevalence(cdm,
                                          nOutcomes = 1,
                                          prevOutcomes = 0.10)
@@ -105,6 +150,33 @@ test_that("redshift test", {
                      prefix = "incp_")
   )
 
+  profvis::profvis({
+    cdm <- generateDenominatorCohortSet(
+      cdm = cdm,
+      name = "denominator",
+      cohortDateRange = as.Date(c("1990-01-01", "2020-12-31")),
+      ageGroup = list(c(18,44), c(45,64),
+                      c(65,74), c(75,100)),
+      sex = c("Male", "Female", "Both"),
+      daysPriorObservation = 1,
+      requirementInteractions=FALSE
+    )
+  })
+
+
+  cdm <- CDMConnector::generateConceptCohortSet(cdm = cdm, name = "test_outcome",
+                                                conceptSet = list("a" = 80502,
+                                                                  "b" = 134736),
+                                                overwrite = TRUE)
+
+expect_no_error(estimateIncidence(
+    cdm = a_cdm,
+    returnParticipants = FALSE,
+    denominatorTable = "denom",
+    outcomeTable = "test_outcome",
+    interval = "years"
+  ))
+
   timings <- benchmarkIncidencePrevalence(cdm,
                                           nOutcomes = 1,
                                           prevOutcomes = 0.10)
@@ -132,11 +204,31 @@ test_that("sql server test", {
                      prefix = "incp_")
   )
 
+
+  cdm <- generateDenominatorCohortSet(
+    cdm = cdm,
+    name = "denom" ,
+    overwrite = TRUE
+  )
+
+  cdm <- CDMConnector::generateConceptCohortSet(cdm = cdm, name = "test_outcome",
+                                                conceptSet = list("a" = 80502,
+                                                                  "b" = 134736),
+                                                overwrite = TRUE)
+
+  estimateIncidence(
+    cdm = cdm,
+    returnParticipants = FALSE,
+    denominatorTable = "denom",
+    outcomeTable = "test_outcome",
+    interval = "years"
+  )
+
   timings <- benchmarkIncidencePrevalence(cdm,
                                                nOutcomes = 1,
                                                prevOutcomes = 0.10)
 
-  CDMConnector::dropTable(cdm = cdm, name = starts_with("incp_"))
+  CDMConnector::dropTable(cdm = cdm, name = tidyselect::starts_with("incp_"))
 
   CDMConnector::cdm_disconnect(cdm = cdm)
 
